==> refcodes-data-2.2.1-sources.jar: org/refcodes/data/AckTimeout.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied), as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.data;

import org.refcodes.mixin.TimeInMsAccessor;

/**
 * The {@link AckTimeout} defines values used inside a Transmit/Acknowledge
 * (ARQ) processing control flow.
 */
public enum AckTimeout implements TimeInMsAccessor {

	// /////////////////////////////////////////////////////////////////////////
	// CODE LOOP SLEEP TIMES:
	// /////////////////////////////////////////////////////////////////////////

	MIN(IoTimeout.MIN.getTimeInMs() / 5), // Must be smaller or at least different than the according IoTimeout!

	NORM(IoTimeout.NORM.getTimeInMs() / 5), // Must be smaller or at least different than the according IoTimeout!

	MAX(IoTimeout.MAX.getTimeInMs() / 5); // Must be smaller or at least different than the according IoTimeout!

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	private int _value;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new io timeout.
	 *
	 * @param aValue the value
	 */
	private AckTimeout( int aValue ) {
		_value = aValue;
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////
	@Override
	public int getTimeInMs() {
		return _value;
	}
}

==> refcodes-data-3.3.7-sources.jar: org/refcodes/data/AckTimeout.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied), as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.data;

import org.refcodes.mixin.TimeMillisAccessor;

/**
 * The {@link AckTimeout} defines values used inside a Transmit/Acknowledge
 * (ARQ) processing control flow.
 */
public enum AckTimeout implements TimeMillisAccessor {

	// /////////////////////////////////////////////////////////////////////////
	// CODE LOOP SLEEP TIMES:
	// /////////////////////////////////////////////////////////////////////////

	MIN(IoTimeout.MIN.getTimeMillis() / 5), // Must be smaller or at least different than the according IoTimeout!

	NORM(IoTimeout.NORM.getTimeMillis() / 5), // Must be smaller or at least different than the according IoTimeout!

	MAX(IoTimeout.MAX.getTimeMillis() / 5); // Must be smaller or at least different than the according IoTimeout!

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	private int _value;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new io timeout.
	 *
	 * @param aValue the value
	 */
	private AckTimeout( int aValue ) {
		_value = aValue;
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////
	@Override
	public int getTimeMillis() {
		return _value;
	}
}
